@@ -137,7 +137,6 @@ def _download_and_unpack_bundle(bundle_type):
     extraction_path = _get_extraction_path(bundle_type)
 
     # Unpack the bundle
-    LOGGER.info("Unpacking {}".format(bundle.name))
     if compression == 'tar.bz2':
         archive = tarfile.open(bundle.name, 'r:bz2')
         _store_bundle_files(archive.getnames(), extraction_path)
@@ -174,7 +173,7 @@ def _get_extraction_path(bundle_type):
     """
     path = '/'
     if sys.platform in ['win32', 'cygwin']:
-        path = 'C:\\'
+        path = 'C:'
 
     if not os.path.exists(path):
         LOGGER.debug('Created extraction path {}'.format(path))
